provider "docker" {
  host = "${trimspace(file("/app/{{ appName }}-{{ dockerHostNodeName }}-ip.txt"))}:8376"
  alias = "{{ dockerHostNodeName }}"
  cert_path = "/home/ubuntu/terraform/certs/${trimspace(file("/app/{{ appName }}-{{ dockerHostNodeName }}-ip.txt"))}/keys"
}


{% if dockerPrivateRegistryIp and dockerPrivateRegistryPort and dockerPrivateRegistryUser and dockerPrivateRegistryPassword %}
resource "null_resource" "{{ imageName|replace("/", "-")  }}-{{ containerName }}" {
  provisioner "remote-exec" {
    inline = [
      "echo 'Performing login...' >> /home/ubuntu/log.txt",
      "docker -H ${trimspace(file("/app/{{ appName }}-{{ dockerHostNodeName }}-ip.txt"))}:8376 --tls=true --tlscert=/home/ubuntu/.docker/client/keys/cert.pem --tlscacert=/home/ubuntu/.docker/client/keys/ca.pem --tlskey=/home/ubuntu/.docker/client/keys/key.pem login {{ dockerPrivateRegistryIp }}:{{ dockerPrivateRegistryPort }} -u {{ dockerPrivateRegistryUser }} -p {{ dockerPrivateRegistryPassword }}",
      "echo '...login done' >> /home/ubuntu/log.txt",
      "echo 'Pulling image...' >> /home/ubuntu/log.txt",
      "docker -H ${trimspace(file("/app/{{ appName }}-{{ dockerHostNodeName }}-ip.txt"))}:8376 --tls=true --tlscert=/home/ubuntu/.docker/client/keys/cert.pem --tlscacert=/home/ubuntu/.docker/client/keys/ca.pem --tlskey=/home/ubuntu/.docker/client/keys/key.pem pull {{ dockerPrivateRegistryIp }}:{{ dockerPrivateRegistryPort }}/{{ imageName }}:{{ imageTag }}",
      "echo '... pull done' >> /home/ubuntu/log.txt",
    ]
    connection {
      host = "${trimspace(file("/app/{{ appName }}-{{ dockerHostNodeName }}-ip.txt"))}"
      type     = "ssh"
      user     = "ubuntu"
      private_key =  "${file("/home/ubuntu/terraform/keypairs/{{ appName }}/private-key-openssh")}"
    }
  }

}
{% else %}


resource "docker_image" "{{ imageName|replace("/", "-") }}-{{ containerName }}" {
  provider = "docker.{{ dockerHostNodeName }}"
  name = "{{ imageName }}:{{ imageTag}}"
}
{% endif %}


resource "docker_container" "{{ containerName }}" {
  provider = "docker.{{ dockerHostNodeName }}"

{% if dockerPrivateRegistryIp and dockerPrivateRegistryPort and dockerPrivateRegistryUser and dockerPrivateRegistryPassword %}
  image =  "{{ dockerPrivateRegistryIp }}:{{ dockerPrivateRegistryPort }}/{{ imageName }}:{{ imageTag }}"
{% else  %}
  image =  "${docker_image.{{ imageName|replace("/", "-") }}-{{ containerName }}.latest}"
{% endif%}
  name  = "{{ containerName }}"
{% if entrypoint %}
  entrypoint = {{ entrypoint }}
{% endif %}
{% if command %}
  command = {{ command }}
{% endif %}
  hostname = "{{ hostname }}"
{% if restart %}
  restart = "{{ restart }}"
{% endif %}
{% if environment %}
  env = {{ environment }}
{% endif %}

{% if networks %}
  networks = [{{ '\"' + networks|join('\", \"') + '\"' }}]
{% endif %}

{% for port in portMapping %}
  ports {
    internal = {{ port['containerPort'] }}
    external = {{ port['hostPort'] }}
  }
{% endfor -%}

{% for volume in volumeMapping %}
  volumes {
  {% if volume['fromContainer'] %}
    from_container = "{{ volume['fromContainer'] }}"
  {% endif %}
  {% if volume['hostPath'] %}
    host_path = "{{ volume['hostPath'] }}"
  {% endif %}
  {% if volume['volumeName'] %}
    volume_name = "{{ volume['volumeName'] }}"
  {% endif %}
  {% if volume['containerPath'] %}
    container_path = "{{ volume['containerPath'] }}"
  {% endif %}
  {% if volume['readOnly'] %}
    read_only = "{{ volume['readOnly'] }}"
  {% endif %}
  }
{% endfor -%}

{% for host  in hostMapping %}
  host {
  {% if host['ip'] %}
    ip = "{{ host['ip'] }}",
  {% elif host['dockerHostNodeName'] %}
    ip = "${trimspace(file("/app/{{ appName }}-{{ dockerHostNodeName }}-ip.txt"))}",
  {% endif %}
    host = "{{ host['host'] }}"
  }
{% endfor %}
{% for capability in capabilities %}
  capabilities {
    add = "{{ capability['cap_add'] }}"
    drop = "{{ capability['cap_drop'] }}"
  }
{% endfor -%}
{% if dockerPrivateRegistryIp and dockerPrivateRegistryPort and dockerPrivateRegistryUser and dockerPrivateRegistryPassword %}
  depends_on = ["null_resource.{{ imageName|replace("/", "-")  }}-{{ containerName }}"]
{% endif %}

{% set depends_networks = [] %}
{% if networksDependencies %}
  depends_on = [{{ '\"' + networksDependencies|join('\", \"') + '\"' }}]
{% endif %}
}

